import React, { useMemo, useRef } from "react";
import { Input, InputRef } from "antd";
import { Node } from "@antv/x6";
import { useSafeState } from "ahooks";
export default function Text(props: {
  value: string;
  styles: React.CSSProperties & {
    bold: boolean;
    italic: boolean;
  };
  node: Node;
  fixedWidth: boolean;
  placeholder?: string;
  txtStyle?: React.CSSProperties;
  onChange?: (value: string) => void;
}) {
  const { value, styles, node, placeholder, txtStyle } = props;
  const [isEditing, setIsEditing] = useSafeState(false);
  const inputRef = useRef<InputRef>(null);

  const style = useMemo((): React.CSSProperties => {
    return {
      ...styles,
      fontWeight: styles.bold ? "bold" : undefined,
      fontStyle: styles.italic ? "italic" : undefined,
      minHeight: "12px",
      padding: 0,
      wordBreak: "break-all",
    };
  }, [styles]);

  const handleChange = (val: string) => {
    node.setData({ label: val });
    props.onChange?.(val);
  };

  const handleSetEditing = (edit: boolean) => {
    if (node.data?.lock) {
      return;
    }
    node.setData({
      ignoreDrag: edit,
    });
    if (edit) {
      setTimeout(() => {
        inputRef.current?.focus({ cursor: "all" });
      }, 100);
    }
    setIsEditing(edit);
  };

  // useEffect(() => {
  //   // 处理字体加载
  //   // @ts-ignore
  //   // WebFont.load({
  //   //   google: {
  //   //     families: [styles.fontFamily]
  //   //   }
  //   // })
  // }, [styles.fontFamily]);

  return (
    <div style={txtStyle}>
      <div
        style={{
          ...style,
          opacity: isEditing ? 0 : 1,
        }}
        onDoubleClick={() => handleSetEditing(true)}
      >
        {value}
      </div>
      {isEditing && (
        <Input.TextArea
          ref={inputRef}
          placeholder={placeholder}
          value={value}
          variant="borderless"
          style={{
            ...style,
            position: "absolute",
            left: 0,
            top: 0
          }}
          onChange={(e) => handleChange(e.target.value)}
          onBlur={() => handleSetEditing(false)}
          autoSize
        />
      )}
    </div>
  );
}
